# `bibl_package2`

second attemp on trying to make a test package for python 

    from mult.mult3 import multiply_by_three
    from div.div3 import divide_by_three

    multiply_by_three(3) # 9
    divide_by_three(12) # 4